# swagger-client
Daily and hourly astronomical data for latitude/longitude points, ZIP/Postal Codes, Designated Market Areas, and OnPoint™ points. The Weather Source Astronomy API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  An API key is required to authorize requests. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). 

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen
For more information, please visit [https://developer.weathersourceapis.com/](https://developer.weathersourceapis.com/)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import swagger_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.DmasApi(swagger_client.ApiClient(configuration))
dma_id = 56 # int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
_date = '2013-10-20' # date | An date formatted as a RFC3339 date value.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # A day of astronomy data for a DMA.
    api_response = api_instance.dmas_dma_id_days_date_get(dma_id, _date, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DmasApi->dmas_dma_id_days_date_get: %s\n" % e)

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.DmasApi(swagger_client.ApiClient(configuration))
dma_id = 56 # int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
date_start = '2013-10-20' # date | An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
date_end = '2013-10-20' # date | An date formatted as a RFC3339 date value that must occur temporally after dateStart.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # A contiguous range of daily astronomy for a DMA.
    api_response = api_instance.dmas_dma_id_days_date_startdate_end_get(dma_id, date_start, date_end, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DmasApi->dmas_dma_id_days_date_startdate_end_get: %s\n" % e)

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.DmasApi(swagger_client.ApiClient(configuration))
dma_id = 56 # int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
timestamp = '2013-10-20T19:20:30+01:00' # datetime | A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # An hour of astronomy data for a DMA
    api_response = api_instance.dmas_dma_id_hours_timestamp_get(dma_id, timestamp, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DmasApi->dmas_dma_id_hours_timestamp_get: %s\n" % e)

# Configure API key authorization: ApiKeyAuth
configuration = swagger_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.DmasApi(swagger_client.ApiClient(configuration))
dma_id = 56 # int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
timestamp_start = '2013-10-20T19:20:30+01:00' # datetime | A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
timestamp_end = '2013-10-20T19:20:30+01:00' # datetime | A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
fields = ['fields_example'] # list[str] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allMoon *(moon related fields)* * allSun *(sun related fields)* * popular *(sunrise, sunset, moonrise, moonset, and moonPhase)* 
unit_scale = 'IMPERIAL' # str | The unit scale for returned values.<br> (optional) (default to IMPERIAL)

try:
    # A contiguous range of hourly astronomy for a DMA.
    api_response = api_instance.dmas_dma_id_hours_timestamp_starttimestamp_end_get(dma_id, timestamp_start, timestamp_end, fields, unit_scale=unit_scale)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DmasApi->dmas_dma_id_hours_timestamp_starttimestamp_end_get: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://astronomy.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DmasApi* | [**dmas_dma_id_days_date_get**](docs/DmasApi.md#dmas_dma_id_days_date_get) | **GET** /dmas/{dmaId}/days/{date} | A day of astronomy data for a DMA.
*DmasApi* | [**dmas_dma_id_days_date_startdate_end_get**](docs/DmasApi.md#dmas_dma_id_days_date_startdate_end_get) | **GET** /dmas/{dmaId}/days/{dateStart},{dateEnd} | A contiguous range of daily astronomy for a DMA.
*DmasApi* | [**dmas_dma_id_hours_timestamp_get**](docs/DmasApi.md#dmas_dma_id_hours_timestamp_get) | **GET** /dmas/{dmaId}/hours/{timestamp} | An hour of astronomy data for a DMA
*DmasApi* | [**dmas_dma_id_hours_timestamp_starttimestamp_end_get**](docs/DmasApi.md#dmas_dma_id_hours_timestamp_starttimestamp_end_get) | **GET** /dmas/{dmaId}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly astronomy for a DMA.
*OnpointsApi* | [**onpoints_onpoint_id_days_date_get**](docs/OnpointsApi.md#onpoints_onpoint_id_days_date_get) | **GET** /onpoints/{onpointId}/days/{date} | A day of astronomy data for an OnPoint™ point.
*OnpointsApi* | [**onpoints_onpoint_id_days_date_startdate_end_get**](docs/OnpointsApi.md#onpoints_onpoint_id_days_date_startdate_end_get) | **GET** /onpoints/{onpointId}/days/{dateStart},{dateEnd} | A contiguous range of daily astronomy for an OnPoint™ point.
*OnpointsApi* | [**onpoints_onpoint_id_hours_timestamp_get**](docs/OnpointsApi.md#onpoints_onpoint_id_hours_timestamp_get) | **GET** /onpoints/{onpointId}/hours/{timestamp} | An hour of astronomy data for an OnPoint™ point.
*OnpointsApi* | [**onpoints_onpoint_id_hours_timestamp_starttimestamp_end_get**](docs/OnpointsApi.md#onpoints_onpoint_id_hours_timestamp_starttimestamp_end_get) | **GET** /onpoints/{onpointId}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly astronomy for an OnPoint™ point.
*PointsApi* | [**points_latitudelongitude_days_date_get**](docs/PointsApi.md#points_latitudelongitude_days_date_get) | **GET** /points/{latitude},{longitude}/days/{date} | A day of astronomy data for a Latitude/Longitude point.
*PointsApi* | [**points_latitudelongitude_days_date_startdate_end_get**](docs/PointsApi.md#points_latitudelongitude_days_date_startdate_end_get) | **GET** /points/{latitude},{longitude}/days/{dateStart},{dateEnd} | A contiguous range of daily astronomy for a Latitude/Longitude point.
*PointsApi* | [**points_latitudelongitude_hours_timestamp_get**](docs/PointsApi.md#points_latitudelongitude_hours_timestamp_get) | **GET** /points/{latitude},{longitude}/hours/{timestamp} | An hour of astronomy data for a Latitude/Longitude point.
*PointsApi* | [**points_latitudelongitude_hours_timestamp_starttimestamp_end_get**](docs/PointsApi.md#points_latitudelongitude_hours_timestamp_starttimestamp_end_get) | **GET** /points/{latitude},{longitude}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly astronomy for a Latitude/Longitude point.
*PostcodesApi* | [**postcodes_postcodecountry_code_days_date_get**](docs/PostcodesApi.md#postcodes_postcodecountry_code_days_date_get) | **GET** /postcodes/{postcode},{countryCode}/days/{date} | A day of astronomy data for a postcode.
*PostcodesApi* | [**postcodes_postcodecountry_code_days_date_startdate_end_get**](docs/PostcodesApi.md#postcodes_postcodecountry_code_days_date_startdate_end_get) | **GET** /postcodes/{postcode},{countryCode}/days/{dateStart},{dateEnd} | A contiguous range of daily astronomy for a postcode.
*PostcodesApi* | [**postcodes_postcodecountry_code_hours_timestamp_get**](docs/PostcodesApi.md#postcodes_postcodecountry_code_hours_timestamp_get) | **GET** /postcodes/{postcode},{countryCode}/hours/{timestamp} | An hour of astronomy data for a postcode.
*PostcodesApi* | [**postcodes_postcodecountry_code_hours_timestamp_starttimestamp_end_get**](docs/PostcodesApi.md#postcodes_postcodecountry_code_hours_timestamp_starttimestamp_end_get) | **GET** /postcodes/{postcode},{countryCode}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly astronomy for a postcode.

## Documentation For Models

 - [AstroRise](docs/AstroRise.md)
 - [AstroSet](docs/AstroSet.md)
 - [AstronomyDayArr](docs/AstronomyDayArr.md)
 - [AstronomyDayObj](docs/AstronomyDayObj.md)
 - [AstronomyDmaDayObj](docs/AstronomyDmaDayObj.md)
 - [AstronomyDmaHourObj](docs/AstronomyDmaHourObj.md)
 - [AstronomyHourArr](docs/AstronomyHourArr.md)
 - [AstronomyHourObj](docs/AstronomyHourObj.md)
 - [AstronomyOnpointDayObj](docs/AstronomyOnpointDayObj.md)
 - [AstronomyOnpointHourObj](docs/AstronomyOnpointHourObj.md)
 - [AstronomyPointDayObj](docs/AstronomyPointDayObj.md)
 - [AstronomyPointHourObj](docs/AstronomyPointHourObj.md)
 - [AstronomyPostcodeDayObj](docs/AstronomyPostcodeDayObj.md)
 - [AstronomyPostcodeHourObj](docs/AstronomyPostcodeHourObj.md)
 - [BoundingPoints](docs/BoundingPoints.md)
 - [BoundingPointsInner](docs/BoundingPointsInner.md)
 - [CivilRise](docs/CivilRise.md)
 - [CivilSet](docs/CivilSet.md)
 - [CountryCode](docs/CountryCode.md)
 - [CountryName](docs/CountryName.md)
 - [DateEnd](docs/DateEnd.md)
 - [DateRangeObj](docs/DateRangeObj.md)
 - [DateStart](docs/DateStart.md)
 - [Distance](docs/Distance.md)
 - [DistancePop](docs/DistancePop.md)
 - [DmaId](docs/DmaId.md)
 - [DmaName](docs/DmaName.md)
 - [DmaObj](docs/DmaObj.md)
 - [ErrorObj](docs/ErrorObj.md)
 - [FieldListDayObj](docs/FieldListDayObj.md)
 - [FieldListHourObj](docs/FieldListHourObj.md)
 - [Fields](docs/Fields.md)
 - [Grid](docs/Grid.md)
 - [Latitude](docs/Latitude.md)
 - [Longitude](docs/Longitude.md)
 - [ModelDate](docs/ModelDate.md)
 - [MoonAge](docs/MoonAge.md)
 - [MoonAzimuth](docs/MoonAzimuth.md)
 - [MoonDistance](docs/MoonDistance.md)
 - [MoonElevation](docs/MoonElevation.md)
 - [MoonIllum](docs/MoonIllum.md)
 - [MoonPhase](docs/MoonPhase.md)
 - [MoonRadius](docs/MoonRadius.md)
 - [Moonrise](docs/Moonrise.md)
 - [Moonset](docs/Moonset.md)
 - [NauticalRise](docs/NauticalRise.md)
 - [NauticalSet](docs/NauticalSet.md)
 - [OnpointId](docs/OnpointId.md)
 - [OnpointObj](docs/OnpointObj.md)
 - [PointObj](docs/PointObj.md)
 - [Population](docs/Population.md)
 - [Postcode](docs/Postcode.md)
 - [PostcodeObj](docs/PostcodeObj.md)
 - [SamplePoints](docs/SamplePoints.md)
 - [SamplePointsInner](docs/SamplePointsInner.md)
 - [SubdivCode](docs/SubdivCode.md)
 - [SubdivName](docs/SubdivName.md)
 - [SunAzimuth](docs/SunAzimuth.md)
 - [SunDistance](docs/SunDistance.md)
 - [SunElevation](docs/SunElevation.md)
 - [SunRadius](docs/SunRadius.md)
 - [SunTransit](docs/SunTransit.md)
 - [Sunrise](docs/Sunrise.md)
 - [Sunset](docs/Sunset.md)
 - [Timestamp](docs/Timestamp.md)
 - [TimestampEnd](docs/TimestampEnd.md)
 - [TimestampRangeObj](docs/TimestampRangeObj.md)
 - [TimestampStart](docs/TimestampStart.md)
 - [Timezone](docs/Timezone.md)

## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author

support@weathersource.com
